@@ -81,12 +81,6 @@ pub struct BlockResult {
     pub block: Block,
 }
 
-#[derive(Deserialize, Serialize, Debug)]
-pub struct ValidatorSetResponse {
-    #[serde(with = "terra_u64_format")]
-    pub height: u64,
-    pub result: ValidatorSetResult,
-}
 #[derive(Deserialize, Serialize, Debug)]
 pub struct ValidatorSetResult {
     #[serde(with = "terra_u64_format")]
